@@ -1,21 +1,9 @@
 /*
  *  commandoptions.cpp  -  extract command line options
  *  Program:  kalarm
- *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "commandoptions.h"
@@ -151,6 +139,12 @@ QStringList CommandOptions::setOptions(QCommandLineParser* parser, const QString
               = new QCommandLineOption(QStringList{QStringLiteral("m"), QStringLiteral("mail")},
                                        i18n("Send an email to the given address (repeat as needed)"),
                                        QStringLiteral("address"));
+    mOptions[NAME]
+              = new QCommandLineOption(QStringList{QStringLiteral("n"), QStringLiteral("name")},
+                                       i18n("Name of alarm"));
+    mOptions[NOTIFY]
+              = new QCommandLineOption(QStringList{QStringLiteral("N"), QStringLiteral("notify")},
+                                       i18n("Display alarm message as a notification"));
     mOptions[PLAY]
               = new QCommandLineOption(QStringList{QStringLiteral("p"), QStringLiteral("play")},
                                        i18n("Audio file to play once"),
@@ -277,7 +271,7 @@ void CommandOptions::process()
     }
     if (checkCommand(OptEDIT_NEW_PRESET, EDIT_NEW_PRESET))
     {
-        mTemplateName = mParser->value(*mOptions.at(mCommandOpt));
+        mName = mParser->value(*mOptions.at(mCommandOpt));
     }
     if (checkCommand(FILE, NEW))
     {
@@ -401,6 +395,7 @@ void CommandOptions::process()
     checkEditType(EditAlarmDlg::DISPLAY, REMINDER_ONCE);
     checkEditType(EditAlarmDlg::DISPLAY, ACK_CONFIRM);
     checkEditType(EditAlarmDlg::DISPLAY, AUTO_CLOSE);
+    checkEditType(EditAlarmDlg::DISPLAY, NOTIFY);
     checkEditType(EditAlarmDlg::EMAIL, SUBJECT);
     checkEditType(EditAlarmDlg::EMAIL, FROM_ID);
     checkEditType(EditAlarmDlg::EMAIL, ATTACH);
@@ -416,6 +411,11 @@ void CommandOptions::process()
         case NEW:
         {
             // Display a message or file, execute a command, or send an email
+            if (mParser->isSet(*mOptions.at(NAME)))
+            {
+                // Alarm name is specified
+                mName = mParser->value(*mOptions.at(NAME));
+            }
             if (mParser->isSet(*mOptions.at(COLOUR)))
             {
                 // Background colour is specified
@@ -596,6 +596,20 @@ void CommandOptions::process()
             else if (mParser->isSet(*mOptions.at(AUTO_CLOSE)))
                 setErrorRequires(AUTO_CLOSE, LATE_CANCEL);
 
+            if (mParser->isSet(*mOptions.at(NOTIFY)))
+            {
+                if (mParser->isSet(*mOptions.at(COLOUR)))
+                    setErrorIncompatible(NOTIFY, COLOUR);
+                if (mParser->isSet(*mOptions.at(COLOURFG)))
+                    setErrorIncompatible(NOTIFY, COLOURFG);
+                if (mParser->isSet(*mOptions.at(ACK_CONFIRM)))
+                    setErrorIncompatible(NOTIFY, ACK_CONFIRM);
+                if (mParser->isSet(*mOptions.at(PLAY)))
+                    setErrorIncompatible(NOTIFY, PLAY);
+                if (mParser->isSet(*mOptions.at(AUTO_CLOSE)))
+                    setErrorIncompatible(NOTIFY, AUTO_CLOSE);
+            }
+
             if (mParser->isSet(*mOptions.at(ACK_CONFIRM)))
                 mFlags |= KAEvent::CONFIRM_ACK;
             if (mParser->isSet(*mOptions.at(AUTO_CLOSE)))
@@ -604,6 +618,8 @@ void CommandOptions::process()
                 mFlags |= KAEvent::BEEP;
             if (mParser->isSet(*mOptions.at(SPEAK)))
                 mFlags |= KAEvent::SPEAK;
+            if (mParser->isSet(*mOptions.at(NOTIFY)))
+                mFlags |= KAEvent::NOTIFY;
             if (mParser->isSet(*mOptions.at(KORGANIZER)))
                 mFlags |= KAEvent::COPY_KORGANIZER;
             if (mParser->isSet(*mOptions.at(DISABLE)))
@@ -649,6 +665,10 @@ void CommandOptions::process()
                 errors << optionName(LATE_CANCEL);
             if (mParser->isSet(*mOptions.at(LOGIN)))
                 errors << optionName(LOGIN);
+            if (mParser->isSet(*mOptions.at(NAME)))
+                errors << optionName(NAME);
+            if (mParser->isSet(*mOptions.at(NOTIFY)))
+                errors << optionName(NOTIFY);
             if (mParser->isSet(*mOptions.at(PLAY)))
                 errors << optionName(PLAY);
             if (mParser->isSet(*mOptions.at(PLAY_REPEAT)))
@@ -659,6 +679,8 @@ void CommandOptions::process()
                 errors << optionName(REMINDER_ONCE);
             if (mParser->isSet(*mOptions.at(SPEAK)))
                 errors << optionName(SPEAK);
+            if (mParser->isSet(*mOptions.at(NOTIFY)))
+                errors << optionName(NOTIFY);
             if (mParser->isSet(*mOptions.at(SUBJECT)))
                 errors << optionName(SUBJECT);
             if (mParser->isSet(*mOptions.at(TIME)))
