@@ -123,9 +123,9 @@ void DirResourceImportDialog::pageChanged(KPageWidgetItem* current, KPageWidgetI
 
     if (current)
     {
-        auto* page = static_cast<DirResourceImportWidgetBase*>(current->widget());
+        auto page = static_cast<DirResourceImportWidgetBase*>(current->widget());
         page->setTextSizes();
-        auto* typePage = qobject_cast<DirResourceImportTypeWidget*>(page);
+        auto typePage = qobject_cast<DirResourceImportTypeWidget*>(page);
         if (typePage)
             typePage->validate();
     }
@@ -138,7 +138,7 @@ void DirResourceImportDialog::pageChanged(KPageWidgetItem* current, KPageWidgetI
 */
 void DirResourceImportDialog::typeStatusChanged(bool ok)
 {
-    auto* page = qobject_cast<DirResourceImportTypeWidget*>(currentPage()->widget());
+    auto page = qobject_cast<DirResourceImportTypeWidget*>(currentPage()->widget());
     if (page)
     {
         nextButton()->setEnabled(ok  &&  (page != mLastPage));
@@ -252,7 +252,7 @@ DirResourceImportTypeWidget::DirResourceImportTypeWidget(CalEvent::Type alarmTyp
     mUi->statusLabel->setText(QString());
     mUi->pathRequester->setFocus();
     mUi->pathRequester->installEventFilter(this);
-    connect(mUi->pathRequester, QOverload<>::of(&KUrlRequester::returnPressed), this, [this]() { validate(); });
+    connect(mUi->pathRequester, QOverload<const QString &>::of(&KUrlRequester::returnPressed), this, [this]() { validate(); });
     connect(mUi->pathRequester, &KUrlRequester::urlSelected, this, [this]() { validate(); });
     connect(mUi->pathRequester, &KUrlRequester::textChanged, this, [this]() { setStatus(false); });
     connect(mUi->nameText, &QLineEdit::textChanged, this, [this]() { validate(); });
@@ -266,7 +266,7 @@ DirResourceImportTypeWidget::DirResourceImportTypeWidget(CalEvent::Type alarmTyp
     mUi->grid->setColumnStretch(1, 1);
 
     importTypeSelected();
-    QTimer::singleShot(0, this, &DirResourceImportTypeWidget::validate);
+    QTimer::singleShot(0, this, &DirResourceImportTypeWidget::validate);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
 }
 
 DirResourceImportTypeWidget::~DirResourceImportTypeWidget()
@@ -432,7 +432,7 @@ void DirResourceImportTypeWidget::validate()
 */
 void DirResourceImportTypeWidget::slotStatJobResult(KJob* job)
 {
-    auto* statJob = static_cast<KIO::StatJob*>(job);
+    auto statJob = static_cast<KIO::StatJob*>(job);
     mStatJob = nullptr;
 
     if (!mCheckingDir)
