@@ -1,7 +1,7 @@
 /*
  *  sounddlg.cpp  -  sound file selection and configuration dialog and widget
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2005-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2005-2021 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -40,6 +40,7 @@
 // Collect these widget labels together to ensure consistent wording and
 // translations across different modules.
 QString SoundWidget::i18n_chk_Repeat()      { return i18nc("@option:check", "Repeat"); }
+QString SoundWidget::i18n_chk_SetVolume()   { return i18nc("@option:check", "Set volume"); }
 
 static const char SOUND_DIALOG_NAME[] = "SoundDialog";
 
@@ -48,7 +49,7 @@ SoundDlg::SoundDlg(const QString& file, float volume, float fadeVolume, int fade
                    const QString& caption, QWidget* parent)
     : QDialog(parent)
 {
-    auto* layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     mSoundWidget = new SoundWidget(true, true, this);
     layout->addWidget(mSoundWidget);
 
@@ -138,7 +139,7 @@ QString SoundWidget::mDefaultDir;
 SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
     : QWidget(parent)
 {
-    auto* layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
 
     QLabel* label = nullptr;
     if (!showPlay)
@@ -149,7 +150,7 @@ SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
 
     QWidget* box = new QWidget(this);
     layout->addWidget(box);
-    auto* boxHLayout = new QHBoxLayout(box);
+    auto boxHLayout = new QHBoxLayout(box);
     boxHLayout->setContentsMargins(0, 0, 0, 0);
     boxHLayout->setSpacing(0);
 
@@ -198,7 +199,7 @@ SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
         mRepeatGroupBox->setWhatsThis(i18nc("@info:whatsthis", "If checked, the sound file will be played repeatedly for as long as the message is displayed."));
         connect(mRepeatGroupBox, &GroupBox::toggled, this, &SoundWidget::changed);
         layout->addWidget(mRepeatGroupBox);
-        auto* glayout = new QVBoxLayout(mRepeatGroupBox);
+        auto glayout = new QVBoxLayout(mRepeatGroupBox);
 
         // Pause between repetitions
         QWidget* box = new QWidget(mRepeatGroupBox);
@@ -223,7 +224,7 @@ SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
     // Volume
     QGroupBox* group = new QGroupBox(i18nc("@title:group Sound volume", "Volume"), this);
     layout->addWidget(group);
-    auto* grid = new QGridLayout(group);
+    auto grid = new QGridLayout(group);
     grid->setColumnStretch(2, 1);
     const int indentWidth = CheckBox::textIndent(this) - grid->horizontalSpacing();
     grid->setColumnMinimumWidth(0, indentWidth);
@@ -234,7 +235,7 @@ SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
     grid->addWidget(box, 1, 0, 1, 3);
     boxHLayout = new QHBoxLayout(box);
     boxHLayout->setContentsMargins(0, 0, 0, 0);
-    mVolumeCheckbox = new CheckBox(i18nc("@option:check", "Set volume"), box);
+    mVolumeCheckbox = new CheckBox(i18n_chk_SetVolume(), box);
     boxHLayout->addWidget(mVolumeCheckbox);
     mVolumeCheckbox->setFixedSize(mVolumeCheckbox->sizeHint());
     connect(mVolumeCheckbox, &CheckBox::toggled, this, &SoundWidget::slotVolumeToggled);
@@ -249,6 +250,9 @@ SoundWidget::SoundWidget(bool showPlay, bool showRepeat, QWidget* parent)
     mVolumeSlider->setWhatsThis(i18nc("@info:whatsthis", "Choose the volume for playing the sound file."));
     mVolumeCheckbox->setFocusWidget(mVolumeSlider);
     connect(mVolumeSlider, &Slider::valueChanged, this, &SoundWidget::changed);
+    label = new QLabel;
+    mVolumeSlider->setValueLabel(label, QStringLiteral("%1%"), true);
+    boxHLayout->addWidget(label);
 
     // Fade checkbox
     mFadeCheckbox = new CheckBox(i18nc("@option:check", "Fade"), group);
@@ -437,7 +441,7 @@ void SoundWidget::playSound()
     mPlayer->setParent(this);
 #else
     mPlayer = new Phonon::MediaObject(this);
-    auto* output = new Phonon::AudioOutput(Phonon::MusicCategory, mPlayer);
+    auto output = new Phonon::AudioOutput(Phonon::MusicCategory, mPlayer);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     mPlayer->setCurrentSource(mUrl);
     Phonon::createPath(mPlayer, output);
 #endif
